@@ -1,4 +1,4 @@
-from .aliases import Context, PTBHandler, ReplyMarkup
+from .aliases import Context, PTBCallback, PTBHandler, ReplyMarkup
 from .bot import Bot
 from .chat import Chat
 from .message import Message
@@ -16,4 +16,5 @@ __all__ = [
     "PTBHandler",
     "Context",
     "ReplyMarkup",
+    "PTBCallback",
 ]
